FancyBorderContainer class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FancyBorderContainer
Constructors
- FancyBorderContainer({Key? key, LinearGradient? outterBorderGradient, EdgeInsetsGeometry? contentPadding, BorderRadiusGeometry? outerBorderRadius, Color? outterBorderSingleColor, required Widget child, EdgeInsets? outterBorderMargin, EdgeInsets? outterBorderPadding, AlignmentGeometry? contentAlignment, BoxConstraints? contentConstraints, Color? contentColor, Decoration? contentDecoration, Clip contentDecorationClipBehavior = Clip.none, Decoration? contentForegroundDecoration, double? contentHeight, EdgeInsetsGeometry? contentMargin, Matrix4? contentTransform, AlignmentGeometry? contentTransformAlignment, double? contentWidth})
-
const
Properties
- child → Widget
-
final
- contentAlignment → AlignmentGeometry?
-
final
- contentColor → Color?
-
final
- contentConstraints → BoxConstraints?
-
final
- contentDecoration → Decoration?
-
final
- contentDecorationClipBehavior → Clip
-
final
- contentForegroundDecoration → Decoration?
-
final
- contentHeight → double?
-
final
- contentMargin → EdgeInsetsGeometry?
-
final
- contentPadding → EdgeInsetsGeometry?
-
final
- contentTransform → Matrix4?
-
final
- contentTransformAlignment → AlignmentGeometry?
-
final
- contentWidth → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- outerBorderRadius → BorderRadiusGeometry?
-
final
- outterBorderGradient → LinearGradient?
-
final
- outterBorderMargin → EdgeInsets?
-
final
- outterBorderPadding → EdgeInsets?
-
final
- outterBorderSingleColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited